pub struct TransactionBatchProcessor<FG: ForkGraph> {
pub check_program_modification_slot: bool,
pub sysvar_cache: RwLock<SysvarCache>,
pub loaded_programs_cache: Arc<RwLock<LoadedPrograms<FG>>>,
/* private fields */
}Fields
check_program_modification_slot: boolsysvar_cache: RwLock<SysvarCache>loaded_programs_cache: Arc<RwLock<LoadedPrograms<FG>>>Implementations
Sourceimpl<FG: ForkGraph> TransactionBatchProcessor<FG>
impl<FG: ForkGraph> TransactionBatchProcessor<FG>
pub fn new( slot: Slot, epoch: Epoch, epoch_schedule: EpochSchedule, fee_structure: FeeStructure, runtime_config: Arc<RuntimeConfig>, loaded_programs_cache: Arc<RwLock<LoadedPrograms<FG>>>, ) -> Self
pub fn load_and_execute_sanitized_transactions<'a, CB: TransactionProcessingCallback>( &self, callbacks: &CB, sanitized_txs: &[SanitizedTransaction], check_results: &mut [TransactionCheckResult], error_counters: &mut TransactionErrorMetrics, enable_cpi_recording: bool, enable_log_recording: bool, enable_return_data_recording: bool, timings: &mut ExecuteTimings, account_overrides: Option<&AccountOverrides>, builtin_programs: impl Iterator<Item = &'a Pubkey>, log_messages_bytes_limit: Option<usize>, ) -> LoadAndExecuteSanitizedTransactionsOutput
Sourcepub fn filter_executable_program_accounts<'a, CB: TransactionProcessingCallback>(
callbacks: &CB,
txs: &[SanitizedTransaction],
lock_results: &mut [TransactionCheckResult],
program_owners: &'a [Pubkey],
) -> HashMap<Pubkey, (&'a Pubkey, u64)>
pub fn filter_executable_program_accounts<'a, CB: TransactionProcessingCallback>( callbacks: &CB, txs: &[SanitizedTransaction], lock_results: &mut [TransactionCheckResult], program_owners: &'a [Pubkey], ) -> HashMap<Pubkey, (&'a Pubkey, u64)>
Returns a hash map of executable program accounts (program accounts that are not writable in the given transactions), and their owners, for the transactions with a valid blockhash or nonce.
pub fn load_program<CB: TransactionProcessingCallback>( &self, callbacks: &CB, pubkey: &Pubkey, reload: bool, effective_epoch: Epoch, ) -> Arc<LoadedProgram>